"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.interpretGitResult = exports.isGitLfsPointerFile = exports.gitLfsPointerFile = void 0;
const child_process = require("child_process");
exports.gitLfsPointerFile = "Git LFS pointer file";
const COMMAND = ["git", ["lfs", "pointer", "--check", "--stdin"]];
function isGitLfsPointerFile(content, command = COMMAND) {
    return interpretGitResult(command, child_process.spawnSync(...command, {
        timeout: 500,
        input: content,
    }));
}
exports.isGitLfsPointerFile = isGitLfsPointerFile;
function interpretGitResult(command, { error, signal, status, stderr }) {
    const commandFailedWith = commandFailed(command);
    if (error !== undefined) {
        return failure(isEnoent(error)
            ? commandFailedWith(`${error.path}: command not found`)
            : commandFailedWith(error.message));
    }
    if (status === null) {
        const shouldNeverHappen = `Neither exit code nor terminating signal was reported for the command '${showCommand(command)}'.`;
        return failure(signal === null
            ? shouldNeverHappen
            : `The command '${showCommand(command)}' was terminated by a ${signal} signal.`);
    }
    if (status === 1 && stderr.includes("is not a git command")) {
        return failure(commandFailedWith(stderr.toString()) + `\nIs Git LFS installed?`);
    }
    if (status > 1) {
        return failure(commandFailedWith(stderr.toString()));
    }
    return { _: "success", isPointerFile: status === 0 };
}
exports.interpretGitResult = interpretGitResult;
function commandFailed(command) {
    return (errorMessage) => `The command '${showCommand(command)}' failed with this error:\n\n${indent(errorMessage.trimEnd())}\n`;
}
function failure(message) {
    return { _: "failure", error: new Error(message) };
}
function showCommand([executable, parameters]) {
    return executable + " " + parameters.join(" ");
}
function isEnoent(error) {
    return error.code === "ENOENT";
}
function indent(text) {
    return text.replace(/^/gm, "    ");
}
